@@ -3,14 +3,13 @@ Definition of the base objects for the creation of a spec validator
 """
 import logging
 import os
+from collections.abc import Mapping
 from io import BytesIO
 from numbers import Integral
 from numbers import Real
 from pathlib import Path
-from pathlib import PurePath
+from typing import Any
 from typing import IO
-from typing import List
-from typing import Tuple
 from typing import Type
 from typing import Union
 
@@ -21,15 +20,16 @@ import voluptuous as vol
 from astropy.io import fits
 from astropy.io.fits.hdu.hdulist import HDUList
 from dkist_fits_specifications import spec214
-from dkist_fits_specifications.utils import expand_naxis
+from dkist_fits_specifications.utils import schema_type_hint
 from voluptuous.error import Invalid
 
 from dkist_header_validator.exceptions import ReturnTypeException
 from dkist_header_validator.exceptions import SpecSchemaDefinitionException
 from dkist_header_validator.exceptions import SpecValidationException
+from dkist_header_validator.exceptions import TranslationException
 from dkist_header_validator.exceptions import ValidationException
 from dkist_header_validator.translator import translate_spec122_to_spec214_l0
-
+from dkist_header_validator.utils.expansions import expand_naxis
 
 logger = logging.getLogger(__name__)
 
@@ -123,14 +123,14 @@ class SpecSchema:
     # Voluptuous schema instance used to validate the definitions
     definition_schema = vol.Schema(definition_schema_definition, extra=vol.ALLOW_EXTRA)
 
-    def __init__(self, spec_schema_definitions: Union[Path, dict, List[dict]]):
+    def __init__(self, spec_schema_definitions: schema_type_hint):
         # convert spec schema definitions to a list of dicts
         self.spec_schema_definitions = self._parse_spec_schema_definitions(spec_schema_definitions)
         # validate the dict definition of the spec schema
         self._validate_spec_schema_definitions()
 
     @classmethod
-    def _parse_spec_schema_definitions(cls, spec_schema: List[dict]) -> dict:
+    def _parse_spec_schema_definitions(cls, spec_schema: schema_type_hint) -> dict[str, Any]:
         """
         Convert from a list of dicts multiple formats to a dict
         :param spec_schema: Definition(s) of the spec's schema
@@ -138,18 +138,24 @@ class SpecSchema:
         """
 
         # Test for proper types and non-emptiness
-        if spec_schema:
-            if all([isinstance(item, dict) and item for item in spec_schema]):
-                schema = {key: schema for item in spec_schema for (key, schema) in item.items()}
-                return schema
-        # empty or not a known type
-        raise SpecSchemaDefinitionException(
-            "Schema definition is empty or is not a supported type",
-            errors={
-                "received": type(spec_schema),
-                "expected": List[dict],
-            },
-        )
+        if not spec_schema:
+            raise SpecSchemaDefinitionException("spec_schema is empty or invalid.")
+
+        if not isinstance(spec_schema, Mapping):
+            raise SpecSchemaDefinitionException(
+                f"spec_schema is not a Mapping it is {type(spec_schema)}"
+            )
+
+        schema = {}
+        for section_name, section_schema in spec_schema.items():
+            if not section_schema:
+                raise SpecSchemaDefinitionException(
+                    f"The {section_name} section has an empty schema: {section_schema!r}"
+                )
+            if not isinstance(section_schema, Mapping):
+                raise SpecSchemaDefinitionException(f"{type(section_schema)} is not a Mapping")
+            schema.update({key: dict(key_schema) for key, key_schema in section_schema.items()})
+        return schema
 
     def _validate_spec_schema_definitions(self) -> None:
         """
@@ -314,10 +320,7 @@ class SpecValidator:
     spec_schema
         Definition of the spec's schema in one of the following forms:
             - SpecSchema instance
-            - Dict definition of the spec schema
-            - List of Dict definitions of the spec schema
-            - Path to a YAML file defining the spec schema
-            - Path to a directory containing YAML files defining spec schema
+            - A dict of sections of key schemas as returned by the fits specification repo
 
     SchemaValidationException
         SpecValidationException or subclass of SpecValidationException
@@ -327,7 +330,7 @@ class SpecValidator:
 
     def __init__(
         self,
-        spec_schema: Union[Path, PurePath, dict, List[dict], SpecSchema],
+        spec_schema: Union[schema_type_hint, SpecSchema],
         SchemaValidationException: Type[SpecValidationException] = SpecValidationException,
     ):
         # Callable for validating a dict against the defined spec_validator
@@ -420,7 +423,7 @@ class SpecValidator:
 
     def _validate_headers(
         self, input_headers: Union[HDUList, dict, fits.header.Header], extra
-    ) -> Tuple[dict, dict]:
+    ) -> tuple[dict, dict]:
         """
         Validates open input headers against the instance spec_schema
         :param input_headers: The input headers to validate in the following formats:
@@ -440,7 +443,7 @@ class SpecValidator:
         verified_headers = self.verify_headers(headers, extra)
         return verified_headers, fits_cards
 
-    def _validate_file(self, input_headers: Union[str, IO], extra) -> Tuple[dict, dict, np.ndarray]:
+    def _validate_file(self, input_headers: Union[str, IO], extra) -> tuple[dict, dict, np.ndarray]:
         """
         Validates files against the astropy and then instance spec_schema
         :param input_headers: The input headers to validate in the following formats:
@@ -469,10 +472,38 @@ class SpecValidator:
                 return verified_headers, fits_cards, data
         except (ValueError, FileNotFoundError, OSError, IndexError) as exc:
             logger.debug(f"Cannot parse headers: detail = {exc}")
-            raise ValidationException(f"Cannot parse headers", errors={type(exc): str(exc)})
+            raise ValidationException("Cannot parse headers", errors={type(exc): str(exc)})
 
     @staticmethod
-    def _return_hdulist(validated_headers, fits_cards) -> HDUList:
+    def _return_HDU(validated_headers, data, fits_cards):
+        """
+        Returns validated headers as an HDU
+        :param validated_headers: Already validated/translated headers to be written out
+          into a FITS file
+        :param data: original data
+        :param fits_cards: Any special cards to be included in the FITS file
+        :return: HDU
+        """
+        new_hdu = fits.PrimaryHDU(data, header=fits.Header())
+        for (key, value) in validated_headers.items():
+            new_hdu.header[key] = value
+        for key in fits_cards:
+            try:
+                if key == "HISTORY":
+                    for line in fits_cards["HISTORY"].splitlines():
+                        new_hdu.header.add_history(line)
+                elif key == "COMMENT":
+                    for line in fits_cards["COMMENT"].splitlines():
+                        new_hdu.header.add_comment(line)
+                else:
+                    new_hdu.header[key] = str(fits_cards[key])
+            except ValueError as e:
+                raise TranslationException("Error writing new header. Invalid header value") from e
+
+        return new_hdu
+
+    @classmethod
+    def _return_hdulist(cls, validated_headers, fits_cards) -> HDUList:
         """
         Returns validated headers as an HDUList
         :param validated_headers: Already validated/translated headers to be written out into
@@ -483,19 +514,7 @@ class SpecValidator:
         if isinstance(validated_headers, HDUList):
             return validated_headers
         temp_array: np.ndarray = np.ones((1, 1, 1), dtype=np.int16)
-        new_hdu = fits.PrimaryHDU(temp_array, header=fits.Header())
-        for (key, value) in validated_headers.items():
-            new_hdu.header[key] = value
-        if "HISTORY" in fits_cards:
-            for line in fits_cards["HISTORY"].splitlines():
-                new_hdu.header.add_history(line)
-            fits_cards.pop("HISTORY")
-        if "COMMENT" in fits_cards:
-            for line in fits_cards["COMMENT"].splitlines():
-                new_hdu.header.add_comment(line)
-            fits_cards.pop("COMMENT")
-        if fits_cards:
-            raise ValueError(f"Invalid keys found in fits_cards. {fits_cards.keys()=}")
+        new_hdu = cls._return_HDU(validated_headers, data=temp_array, fits_cards=fits_cards)
         new_hdu_list = fits.HDUList([new_hdu])
         return new_hdu_list
 
@@ -512,8 +531,8 @@ class SpecValidator:
             validated_headers[key] = str(fits_cards[key])
         return validated_headers
 
-    @staticmethod
-    def _return_BytesIO(validated_headers, input_headers, data, fits_cards) -> BytesIO:
+    @classmethod
+    def _return_BytesIO(cls, validated_headers, input_headers, data, fits_cards) -> BytesIO:
         """
         Returns validated headers as a BytesIO object
         :param validated_headers: Already validated/translated headers to be written out into
@@ -523,11 +542,7 @@ class SpecValidator:
         :param fits_cards: Any special cards to be included in the BytesIO object
         :return: BytesIO object
         """
-        new_hdu = fits.PrimaryHDU(data, header=fits.Header())
-        for (key, value) in validated_headers.items():
-            new_hdu.header[key] = value
-        for key in fits_cards:
-            new_hdu.header[key] = str(fits_cards[key])
+        new_hdu = cls._return_HDU(validated_headers, data, fits_cards)
         new_hdu_list = fits.HDUList([new_hdu])
         return BytesIO(
             new_hdu_list.writeto(
@@ -538,8 +553,8 @@ class SpecValidator:
             )
         )
 
-    @staticmethod
-    def _return_file(validated_headers, input_headers, data, fits_cards) -> (str, IO):
+    @classmethod
+    def _return_file(cls, validated_headers, input_headers, data, fits_cards) -> (str, IO):
         """
         Returns validated headers as a FITS file
         :param validated_headers: Already validated/translated headers to be written out
@@ -549,11 +564,7 @@ class SpecValidator:
         :param fits_cards: Any special cards to be included in the FITS file
         :return: FITS file
         """
-        new_hdu = fits.PrimaryHDU(data, header=fits.Header())
-        for (key, value) in validated_headers.items():
-            new_hdu.header[key] = value
-        for key in fits_cards:
-            new_hdu.header[key] = str(fits_cards[key])
+        new_hdu = cls._return_HDU(validated_headers, data, fits_cards)
         new_hdu_list = fits.HDUList([new_hdu])
         new_hdu_list.writeto(
             str(os.path.basename(input_headers)),
@@ -563,23 +574,6 @@ class SpecValidator:
         )
         return Path(os.path.basename(input_headers))
 
-    @staticmethod
-    def _return_HDU(validated_headers, data, fits_cards):
-        """
-        Returns validated headers as an HDU
-        :param validated_headers: Already validated/translated headers to be written out
-          into a FITS file
-        :param data: original data
-        :param fits_cards: Any special cards to be included in the FITS file
-        :return: HDU
-        """
-        new_hdu = fits.PrimaryHDU(data, header=fits.Header())
-        for (key, value) in validated_headers.items():
-            new_hdu.header[key] = value
-        for key in fits_cards:
-            new_hdu.header[key] = str(fits_cards[key])
-        return new_hdu
-
     def _format_output(
         self, return_type, validated_headers, input_headers=None, data=None, fits_cards=None
     ):
@@ -618,6 +612,9 @@ class SpecValidator:
         if "COMMENT" in validated_headers:
             fits_cards["COMMENT"] = str(validated_headers["COMMENT"])
             validated_headers.pop("COMMENT")
+        # Remove any blank cards
+        if "" in validated_headers:
+            validated_headers.pop("")
         return fits_cards
 
     def validate(self, input_headers, return_type=HDUList, extra=True):
