@@ -36,6 +36,12 @@ class SpecValidationException(ValidationException):
     """
 
 
+class TranslationException(ValidationException):
+    """
+    Exception when translating
+    """
+
+
 class ReturnTypeException(Exception):
     """
     Exception when returning a BytesIO object
