@@ -29,10 +29,8 @@ class Spec122ValidationException(SpecValidationException):
     """
 
 
-spec122 = list(spec122.load_spec122().values())
-
 spec122_validator = SpecValidator(
-    spec_schema=spec122,
+    spec_schema=spec122.load_spec122(),
     SchemaValidationException=Spec122ValidationException,
 )
 
@@ -46,17 +44,12 @@ class Spec214ValidationException(SpecValidationException):
     """
 
 
-spec214_l0 = list(level0.load_level0_spec214().values())
-
 spec214_l0_validator = SpecValidator(
-    spec_schema=spec214_l0,
+    spec_schema=level0.load_level0_spec214(),
     SchemaValidationException=Spec214ValidationException,
 )
 
-spec214 = list(spec214.load_spec214().values())
-
-
 spec214_validator = SpecValidator(
-    spec_schema=spec214,
+    spec_schema=spec214.load_spec214(),
     SchemaValidationException=Spec214ValidationException,
 )
