@@ -9,7 +9,15 @@ from astropy.wcs import WCS
 from dkist_data_simulator.spec122 import Spec122Dataset
 from dkist_data_simulator.spec214 import Spec214Dataset
 
-FITS_OBJECT_TYPES = ["fits", "dict", "hdulist", "header"]
+FITS_OBJECT_TYPES = [
+    "fits",
+    "dict",
+    "hdulist",
+    "header",
+    "multiple_fits_cards_fits",
+    "multiple_fits_cards_hdulist",
+    "multiple_fits_cards_header",
+]
 
 
 def get_fits_object(
@@ -26,6 +34,10 @@ def get_fits_object(
     hdulist : headers built into a PrimaryHDU presented in an HDUList
     header : headers formatted as a fits.header.Header
     second_hdu: a fits file on disk with the headers located in the second hdu
+
+    multiple_fits_cards_fits: a fits file on disk that has multiple fits_cards
+    multiple_fits_cards_hdulist: headers built into a PrimaryHDU presented in an HDUList with multiple fits_cards
+    multiple_fits_cards_header: headers formatted as a fits.header.Header with multiple fits_cards
     """
     header_dict = [d.header(required_only=required_only, expected_only=expected_only) for d in ds][
         0
@@ -76,6 +88,22 @@ def get_fits_object(
         hdu_list.writeto(str(file_name))
         return str(file_name)
 
+    history_card1 = "history card 1"
+    history_card2 = "history card 2"
+    hdu.header.add_history(history_card1)
+    hdu.header.add_history(history_card2)
+    if object_type == "multiple_fits_cards_header":
+        return hdu.header
+
+    hdu_list = fits.HDUList([hdu])
+    if object_type == "multiple_fits_cards_hdulist":
+        return hdu_list
+
+    if object_type == "multiple_fits_cards_fits":
+        file_name = tmpdir / f"{uuid4().hex}.fits"
+        hdu_list.writeto(str(file_name))
+        return str(file_name)
+
 
 class BaseSpec122Dataset(Spec122Dataset):
     def __init__(self, instrument="vbi"):
