@@ -17,72 +17,24 @@ from dkist_header_validator.exceptions import SpecValidationException
 from dkist_header_validator.exceptions import ValidationException
 
 
-@pytest.fixture(scope="module")
-def valid_definition_format_params(tmpdir_factory):
-    """
-    Create a dict of valid schema definition formats to be used in
-    successful format tests below.
-    """
-
-    dict1 = {
-        "key_001": {
-            "expand": True,
-            "required": False,
-            "comment": "comment 1",
-            "type": "float",
-            "values": [
-                1.2,
-                3.1,
-            ],
-        },
-        "key_002": {
-            "expand": False,
-            "required": True,
-            "comment": "comment 2",
-            "type": "str",
-        },
-    }
-
-    dict2 = {
-        "key_003": {
-            "expand": False,
-            "required": True,
-            "comment": "comment 3",
-            "type": "int",
-        },
-        "key_004": {
-            "expand": True,
-            "required": False,
-            "comment": "comment 4",
-            "type": "bool",
-        },
-    }
-
-    test_params = {
-        "valid list[dicts]": [{**dict1, **dict2}],
-    }
-
-    yield test_params
-
-
-@pytest.fixture(
-    scope="function",
-    params=[
-        "valid list[dicts]",
-    ],
-)
-def valid_definition_format(request, valid_definition_format_params):
-    yield valid_definition_format_params[request.param]
-
-
-def test_parse_spec_schema_definitions(valid_definition_format):
+def test_parse_spec_schema_definitions():
     """
     Given: A valid schema definition, can be in one of the following formats:
-        list[dicts]
+        dict[str, dict[str, Any]]
     When: Validating the schema
     Then: SpecSchema(definition) returns the schema definition in dict form
     """
-    SpecSchema._parse_spec_schema_definitions(valid_definition_format)
+    example_schema = {
+        "fits": {
+            "key_004": {
+                "expand": True,
+                "required": False,
+                "comment": "comment 4",
+                "type": "bool",
+            }
+        }
+    }
+    SpecSchema._parse_spec_schema_definitions(example_schema)
 
 
 @pytest.fixture(scope="module")
@@ -91,18 +43,15 @@ def invalid_definition_format_params(tmpdir_factory):
     Create a dict of invalid schema definition formats to be used in
     failing format tests below.
     """
-
-    invalid_list = [{"specxxx": {"not valid"}}, {"this is not a valid yaml file"}]
+    invalid_dict = {"specxxx": {"this is not a valid yaml file"}}
 
     temp_dir = tmpdir_factory.mktemp("invalid_definitions_temp")
     file_name = temp_dir.join("invalid_yaml_file.yml")
-    file_name.write(yaml.safe_dump_all(invalid_list))
+    file_name.write(yaml.safe_dump_all(invalid_dict))
 
     test_params = {
         "invalid Dict": dict(),
-        "invalid List[Dict]": [dict(), dict()],
         "invalid schema type1": "non valid schema type",
-        "empty list": [],
     }
 
     yield test_params
@@ -112,9 +61,7 @@ def invalid_definition_format_params(tmpdir_factory):
     scope="function",
     params=[
         "invalid Dict",
-        "invalid List[Dict]",
         "invalid schema type1",
-        "empty list",
     ],
 )
 def invalid_definition_format(request, invalid_definition_format_params):
@@ -140,41 +87,41 @@ def valid_schema_definition_params():
     """
 
     test_params = {
-        "required int": [{"keyword_name": {"required": True, "type": "int"}}],
-        "optional int": [{"keyword_name": {"required": False, "type": "int"}}],
-        "required float": [{"keyword_name": {"required": True, "type": "float"}}],
-        "optional float": [{"keyword_name": {"required": False, "type": "float"}}],
-        "required str": [{"keyword_name": {"required": True, "type": "str"}}],
-        "optional str": [{"keyword_name": {"required": False, "type": "str"}}],
-        "required bool": [{"keyword_name": {"required": True, "type": "bool"}}],
-        "optional bool": [{"keyword_name": {"required": False, "type": "bool"}}],
-        "optional key-value pair 1": [
-            {"keyword_name": {"required": True, "type": "int", "optional1": "value1"}}
-        ],
-        "optional key-value pair 2": [
-            {"keyword_name": {"required": False, "type": "int", "optional2": "value2"}}
-        ],
-        "optional key-value pair 3": [
-            {"keyword_name": {"required": True, "type": "float", "optional3": "value3"}}
-        ],
-        "optional key-value pair 4": [
-            {"keyword_name": {"required": False, "type": "float", "optional4": "value4"}}
-        ],
-        "optional key-value pair 5": [
-            {"keyword_name": {"required": True, "type": "str", "optional5": "value5"}}
-        ],
-        "optional key-value pair 6": [
-            {"keyword_name": {"required": False, "type": "str", "optional6": "value6"}}
-        ],
-        "optional key-value pair 7": [
-            {"keyword_name": {"required": True, "type": "bool", "optional7": "value7"}}
-        ],
-        "optional key-value pair 8": [
-            {"keyword_name": {"required": False, "type": "bool", "optional8": "value8"}}
-        ],
+        "required int": {"fits": {"keyword_name": {"required": True, "type": "int"}}},
+        "optional int": {"fits": {"keyword_name": {"required": False, "type": "int"}}},
+        "required float": {"fits": {"keyword_name": {"required": True, "type": "float"}}},
+        "optional float": {"fits": {"keyword_name": {"required": False, "type": "float"}}},
+        "required str": {"fits": {"keyword_name": {"required": True, "type": "str"}}},
+        "optional str": {"fits": {"keyword_name": {"required": False, "type": "str"}}},
+        "required bool": {"fits": {"keyword_name": {"required": True, "type": "bool"}}},
+        "optional bool": {"fits": {"keyword_name": {"required": False, "type": "bool"}}},
+        "optional key-value pair 1": {
+            "fits": {"keyword_name": {"required": True, "type": "int", "optional1": "value1"}}
+        },
+        "optional key-value pair 2": {
+            "fits": {"keyword_name": {"required": False, "type": "int", "optional2": "value2"}}
+        },
+        "optional key-value pair 3": {
+            "fits": {"keyword_name": {"required": True, "type": "float", "optional3": "value3"}}
+        },
+        "optional key-value pair 4": {
+            "fits": {"keyword_name": {"required": False, "type": "float", "optional4": "value4"}}
+        },
+        "optional key-value pair 5": {
+            "fits": {"keyword_name": {"required": True, "type": "str", "optional5": "value5"}}
+        },
+        "optional key-value pair 6": {
+            "fits": {"keyword_name": {"required": False, "type": "str", "optional6": "value6"}}
+        },
+        "optional key-value pair 7": {
+            "fits": {"keyword_name": {"required": True, "type": "bool", "optional7": "value7"}}
+        },
+        "optional key-value pair 8": {
+            "fits": {"keyword_name": {"required": False, "type": "bool", "optional8": "value8"}}
+        },
     }
 
-    yield test_params
+    return test_params
 
 
 @pytest.fixture(
@@ -219,23 +166,12 @@ def invalid_schema_definition_params():
     Create a dict of invalid schema definition parameters to be used in
     failing tests below.
     """
+
     test_params = {
-        "missing required": [
-            {"specxxx": {"section": "spec_section", "copy": False}},
-            {"keyword": {"type": "int"}},
-        ],
-        "missing type": [
-            {"specxxx": {"section": "spec_section", "copy": False}},
-            {"keyword": {"required": True}},
-        ],
-        "missing both, no optional": [
-            {"specxxx": {"section": "spec_section", "copy": False}},
-            {"keyword": {}},
-        ],
-        "missing both, with optional": [
-            {"specxxx": {"section": "spec_section", "copy": False}},
-            {"keyword": {"optional": "value"}},
-        ],
+        "missing required": {"specxxx": {"keyword": {"type": "int"}}},
+        "missing type": {"specxxx": {"keyword": {"required": True}}},
+        "missing both, no optional": {"specxxx": {"keyword": {}}},
+        "missing both, with optional": {"specxxx": {"keyword": {"optional": "value"}}},
     }
 
     yield test_params
@@ -261,7 +197,6 @@ def test_validate_spec_schema_definitions_fail(invalid_schema_definition):
     When: Validating the schema
     Then: SpecSchema(definition) raises a SpecSchemaDefinitionException
     """
-
     with pytest.raises(SpecSchemaDefinitionException):
         SpecSchema(invalid_schema_definition)
 
@@ -295,7 +230,9 @@ def test_validate_spec_schema_definitions_values_list(valid_values_list):
     When: Validating the schema
     Then: SpecSchema(definition) does not raise a SpecSchemaDefinitionException
     """
-    test_schema = [{"keyword_name": {"required": True, "type": "int", "values": valid_values_list}}]
+    test_schema = {
+        "fits": {"keyword_name": {"required": True, "type": "int", "values": valid_values_list}}
+    }
     SpecSchema(test_schema)
 
 
@@ -328,10 +265,16 @@ def test_validate_spec_schema_definitions_values_list_fail(invalid_values_list):
     When: Validating the schema
     Then: SpecSchema(definition) raises a SpecSchemaDefinitionException
     """
-    test_schema = [
-        {"specxxx": {"section": "spec_section", "copy": False}},
-        {"keyword_name": {"required": True, "type": "int", "values": invalid_values_list}},
-    ]
+    test_schema = {
+        "fits": {
+            "keyword_name": {
+                "required": True,
+                "type": "int",
+                "values": invalid_values_list,
+            }
+        }
+    }
+
     with pytest.raises(SpecSchemaDefinitionException):
         SpecSchema(test_schema)
 
@@ -342,8 +285,8 @@ def define_test_schema_definition():
     Create a test schema to be used tested against in both successful and failing
     tests below.
     """
-    test_schema_definition = [
-        {
+    test_schema_definition = {
+        "fits": {
             "key_001": {
                 "expand": False,
                 "required": False,
@@ -369,7 +312,7 @@ def define_test_schema_definition():
                 "type": "bool",
             },
         }
-    ]
+    }
 
     yield test_schema_definition
 
@@ -397,7 +340,7 @@ def test_create_spec_schema_fail(define_test_schema_definition):
     schema = SpecSchema(define_test_schema_definition)
 
     # Required key key_003 is missing:
-    input_dict = [{"key_002": "value_002", "key_004": False, "key_001": 3.14159}]
+    input_dict = {"fits": {"key_002": "value_002", "key_004": False, "key_001": 3.14159}}
     with pytest.raises(vol.MultipleInvalid):
         schema(input_dict, extra=True)
 
@@ -407,8 +350,8 @@ def spec_validator():
     """
     Create a schema validator to test fits headers against below.
     """
-    test_schema = [
-        {
+    test_schema = {
+        "fits": {
             "BITPIX": {
                 "expand": False,
                 "required": True,
@@ -420,7 +363,7 @@ def spec_validator():
             "NAXIS2": {"expand": False, "required": True, "type": "int"},
             "NAXIS3": {"expand": False, "required": True, "type": "int", "default_value": 1},
         }
-    ]
+    }
 
     spec_schema = SpecSchema(test_schema)
     spec_validator = SpecValidator(spec_schema)
@@ -523,9 +466,7 @@ def invalid_test_header_params(tmpdir_factory):
     }
 
 
-@pytest.fixture(
-    scope="function", params=["invalid_hdu_list", "invalid_fits_header", "invalid_fits_file"]
-)
+@pytest.fixture(scope="function", params=["invalid_hdu_list", "invalid_fits_file"])
 def invalid_test_header(request, invalid_test_header_params):
     yield invalid_test_header_params[request.param]
 
