@@ -1,4 +1,5 @@
 import pytest
+from astropy.io import fits
 
 from dkist_header_validator.translator import sanitize_to_spec214_level1
 from dkist_header_validator.translator import translate_spec122_to_spec214_l0
@@ -57,10 +58,9 @@ def test_sanitize_s122(valid_translator_object):
     Tries to sanitize a Spec-0122 object
     Given: A valid SPEC-0122 object
     When: Stripping down headers to 214 L1 (no 122 headers)
-    Then: Raises a TypeError exception
+    Then: Returns a header
     """
-    with pytest.raises(TypeError):
-        sanitize_to_spec214_level1(valid_translator_object)
+    sanitize_to_spec214_level1(valid_translator_object)
 
 
 def test_sanitize_translated_s214l0(valid_translator_object):
@@ -68,11 +68,10 @@ def test_sanitize_translated_s214l0(valid_translator_object):
     Tries to sanitize a Spec-214 L0 object
     Given: A valid SPEC-0122 object
     When: Translating and stripping down headers to 214 L1 (no 122 headers)
-    Then: Raises a TypeError exception
+    Then: Returns a header
     """
     s214_l0_header = translate_spec122_to_spec214_l0(valid_translator_object)
-    with pytest.raises(TypeError):
-        sanitize_to_spec214_level1(s214_l0_header)
+    isinstance(sanitize_to_spec214_level1(s214_l0_header), fits.Header)
 
 
 def test_sanitize(valid_spec_214_no_file):
@@ -83,4 +82,4 @@ def test_sanitize(valid_spec_214_no_file):
     Then: For a header or a dict, return a fits header and do not raise an exception
           For an HDUList or a file, return an HDUList and do not raise an exception
     """
-    sanitize_to_spec214_level1(valid_spec_214_no_file)
+    isinstance(sanitize_to_spec214_level1(valid_spec_214_no_file), fits.Header)
