@@ -11,12 +11,12 @@ from typing import Union
 
 from astropy.io import fits
 from astropy.io.fits.hdu.hdulist import HDUList
-from dkist_fits_specifications.spec214 import expand_index_d
 from dkist_fits_specifications.spec214 import level0
 from dkist_fits_specifications.spec214 import load_expanded_spec214
 from dkist_fits_specifications.spec214 import load_spec214
-from dkist_fits_specifications.utils import expand_naxis
 
+from dkist_header_validator.utils.expansions import expand_index_d
+from dkist_header_validator.utils.expansions import expand_naxis
 
 logger = logging.getLogger(__name__)
 
@@ -34,7 +34,14 @@ def translate_spec122_to_spec214_l0(
 ) -> Union[dict, HDUList]:
     """
     Convert spec 122 headers to spec 214 l0 headers
-    :param spec122_input: Spec 122 headers or headers + data to convert
+
+    Parameters
+    ----------
+    spec122_input
+        Spec 122 headers or headers + data to convert
+    Returns
+    -------
+    spec214 l0 headers and (possibly) data
     """
     # extract headers and data
     input_headers, input_data = _parse_fits_like_input(spec122_input)
@@ -50,6 +57,17 @@ def translate_spec122_to_spec214_l0(
 def sanitize_to_spec214_level1(
     input_headers: Union[HDUList, dict, fits.header.Header, str, IO, List]
 ) -> Union[dict, HDUList]:
+    """
+    Remove all non-214 compliant header values
+
+    Parameters
+    ----------
+    input_headers
+        Spec 214 headers or headers + data to convert
+    Returns
+    -------
+        spec214 l1 headers and (possibly) data
+    """
     # extract headers and data
     input_headers, input_data = _parse_fits_like_input(input_headers)
     header = fits.Header(input_headers)
@@ -63,6 +81,7 @@ def sanitize_to_spec214_level1(
 
     if input_data is not None:  # return hdu list if the input had data
         return _format_output_hdu(header, input_data)
+    print(header)
     return header  # return headers if only headers were given
 
 
@@ -71,6 +90,14 @@ def remove_extra_axis_keys(
 ) -> Union[dict, HDUList]:
     """
     Remove all keywords that refer to axes that don't exist in the data array
+
+    Parameters
+    ----------
+    input_headers
+        Spec 214 headers or headers + data
+    Returns
+    -------
+    Stripped headers and (possibly) data
     """
     # extract headers and data
     input_headers, input_data = _parse_fits_like_input(input_headers)
